[Libreoffice-commits] core.git: filter/source lotuswordpro/source offapi/com sc/source sw/inc sw/qa sw/source writerfilter/source

Jan Holesovsky kendy at collabora.com
Fri Oct 4 03:25:54 PDT 2013


 filter/source/graphicfilter/icgm/classx.cxx       |    2 
 lotuswordpro/source/filter/lwpfrib.cxx            |   16 +++----
 lotuswordpro/source/filter/lwpfrib.hxx            |    4 -
 lotuswordpro/source/filter/lwpglobalmgr.cxx       |    2 
 lotuswordpro/source/filter/lwpglobalmgr.hxx       |    2 
 lotuswordpro/source/filter/lwpoverride.cxx        |    2 
 lotuswordpro/source/filter/lwpoverride.hxx        |    2 
 offapi/com/sun/star/style/CharacterProperties.idl |    2 
 sc/source/ui/inc/anyrefdg.hxx                     |    2 
 sc/source/ui/inc/highred.hxx                      |    2 
 sc/source/ui/miscdlgs/anyrefdg.cxx                |   10 ++--
 sc/source/ui/miscdlgs/highred.cxx                 |    6 +-
 sw/inc/charatr.hxx                                |    6 +-
 sw/inc/format.hxx                                 |    2 
 sw/inc/swatrset.hxx                               |    2 
 sw/qa/extras/ooxmlexport/ooxmlexport.cxx          |   46 +++++++++++-----------
 sw/source/core/inc/swfont.hxx                     |   10 ++--
 sw/source/core/text/atrstck.cxx                   |    2 
 sw/source/core/text/inftxt.cxx                    |    4 -
 sw/source/core/txtnode/swfont.cxx                 |   10 ++--
 sw/source/core/unocore/unoprnms.cxx               |    2 
 sw/source/filter/ww8/attributeoutputbase.hxx      |    2 
 sw/source/filter/ww8/docxattributeoutput.cxx      |    6 +-
 sw/source/filter/ww8/docxattributeoutput.hxx      |    6 +-
 sw/source/filter/ww8/rtfattributeoutput.hxx       |    2 
 sw/source/filter/ww8/ww8atr.cxx                   |    2 
 sw/source/filter/ww8/ww8attributeoutput.hxx       |    2 
 writerfilter/source/dmapper/PropertyIds.cxx       |    2 
 28 files changed, 79 insertions(+), 79 deletions(-)

New commits:
commit 2997d7d10a79917495a310135f863bd71541b304
Author: Jan Holesovsky <kendy at collabora.com>
Date:   Fri Oct 4 09:12:07 2013 +0200

    HighLight -> Highlight.
    
    Change-Id: I2db5102fbc441c0b79d8c28023f3e3bb5613b3cf

diff --git a/filter/source/graphicfilter/icgm/classx.cxx b/filter/source/graphicfilter/icgm/classx.cxx
index d0275da..9fb3607 100644
--- a/filter/source/graphicfilter/icgm/classx.cxx
+++ b/filter/source/graphicfilter/icgm/classx.cxx
@@ -207,7 +207,7 @@ void CGM::ImplDoClass8()
         case 0x02 : /*Inheritance Filter */break;               // NS
         case 0x03 : /*Clip Inheritance */break;                 // NS
         case 0x04 : /*Segment Transformation */break;
-        case 0x05 : /*Segment HighLighting */break;             // NS
+        case 0x05 : /*Segment Highlighting */break;             // NS
         case 0x06 : /*Segment Display Priority */break;         // NS
         case 0x07 : /*Segment Pick Priority */break;            // NS
         case 0xfe : /*INQ Current Position */break;
diff --git a/lotuswordpro/source/filter/lwpfrib.cxx b/lotuswordpro/source/filter/lwpfrib.cxx
index d801d42..9ef736d 100644
--- a/lotuswordpro/source/filter/lwpfrib.cxx
+++ b/lotuswordpro/source/filter/lwpfrib.cxx
@@ -111,7 +111,7 @@ LwpFrib* LwpFrib::CreateFrib(LwpPara* pPara, LwpObjectStream* pObjStrm, sal_uInt
         pModInfo->RevisionFlag = sal_False;
         pModInfo->HasCharStyle = sal_False;
         pModInfo->HasLangOverride = sal_False;
-        pModInfo->HasHighLight = sal_False;
+        pModInfo->HasHighlight = sal_False;
         ReadModifiers( pObjStrm, pModInfo );
     }
 
@@ -230,7 +230,7 @@ void LwpFrib::RegisterStyle(LwpFoundry* pFoundry)
 {
     if (!m_pModifiers)
         return;
-    if (!m_pModifiers->FontID && !m_pModifiers->HasCharStyle && !m_pModifiers->HasHighLight)
+    if (!m_pModifiers->FontID && !m_pModifiers->HasCharStyle && !m_pModifiers->HasHighlight)
     {
         m_ModFlag = sal_False;
         return;
@@ -271,9 +271,9 @@ void LwpFrib::RegisterStyle(LwpFoundry* pFoundry)
         }
     }
 
-    if (m_pModifiers->HasHighLight)
+    if (m_pModifiers->HasHighlight)
     {
-        XFColor  aColor = GetHighLightColor();//right yellow
+        XFColor  aColor = GetHighlightColor();//right yellow
         if (pStyle)//change the style directly
             pStyle->GetFont()->SetBackColor(aColor);
         else //register a new style
@@ -347,8 +347,8 @@ void LwpFrib::ReadModifiers(LwpObjectStream* pObjStrm,ModifierInfo* pModInfo)
                 break;
             case FRIB_MTAG_ATTRIBUTE:
                 pModInfo->aTxtAttrOverride.Read(pObjStrm);
-                if (pModInfo->aTxtAttrOverride.IsHighLight())
-                    pModInfo->HasHighLight = sal_True;
+                if (pModInfo->aTxtAttrOverride.IsHighlight())
+                    pModInfo->HasHighlight = sal_True;
                 break;
             case FRIB_MTAG_REVISION:
                 pModInfo->RevisionType = pObjStrm->QuickReaduInt8();
@@ -424,10 +424,10 @@ OUString LwpFrib::GetEditor()
     return pGlobal->GetEditorName(m_nEditor);
 }
 
-XFColor LwpFrib::GetHighLightColor()
+XFColor LwpFrib::GetHighlightColor()
 {
     LwpGlobalMgr* pGlobal = LwpGlobalMgr::GetInstance();
-    return pGlobal->GetHighLightColor(m_nEditor);
+    return pGlobal->GetHighlightColor(m_nEditor);
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/lotuswordpro/source/filter/lwpfrib.hxx b/lotuswordpro/source/filter/lwpfrib.hxx
index 24d1e37..6f9cd40 100644
--- a/lotuswordpro/source/filter/lwpfrib.hxx
+++ b/lotuswordpro/source/filter/lwpfrib.hxx
@@ -81,7 +81,7 @@ struct ModifierInfo
     sal_uInt16 CodePage;
     sal_Bool HasCharStyle;
     sal_Bool HasLangOverride;
-    sal_Bool HasHighLight;
+    sal_Bool HasHighlight;
     sal_uInt8 RevisionType;
     sal_Bool RevisionFlag;
 };
@@ -102,7 +102,7 @@ public:
     void SetType(sal_uInt8 type) { m_nFribType = type;}
     void SetEditor(sal_uInt8 editor) { m_nEditor = editor;}
     OUString GetEditor();
-    XFColor GetHighLightColor();
+    XFColor GetHighlightColor();
 protected:
     LwpPara* m_pPara;
     LwpFrib* m_pNext;
diff --git a/lotuswordpro/source/filter/lwpglobalmgr.cxx b/lotuswordpro/source/filter/lwpglobalmgr.cxx
index b3eb7e0..dfded6b 100644
--- a/lotuswordpro/source/filter/lwpglobalmgr.cxx
+++ b/lotuswordpro/source/filter/lwpglobalmgr.cxx
@@ -146,7 +146,7 @@ OUString LwpGlobalMgr::GetEditorName(sal_uInt8 nID)
     return A2OUSTR("");
 }
 
-XFColor LwpGlobalMgr::GetHighLightColor(sal_uInt8 nID)
+XFColor LwpGlobalMgr::GetHighlightColor(sal_uInt8 nID)
 {
     std::map<sal_uInt16,LwpEditorAttr*>::iterator iter;
 
diff --git a/lotuswordpro/source/filter/lwpglobalmgr.hxx b/lotuswordpro/source/filter/lwpglobalmgr.hxx
index 42cef4c..228d534 100644
--- a/lotuswordpro/source/filter/lwpglobalmgr.hxx
+++ b/lotuswordpro/source/filter/lwpglobalmgr.hxx
@@ -88,7 +88,7 @@ public:
     XFStyleManager* GetXFStyleManager(){return m_pXFStyleManager;}
     void SetEditorAttrMap(sal_uInt16 nID, LwpEditorAttr* pAttr);
     OUString GetEditorName(sal_uInt8 nID);
-    XFColor GetHighLightColor(sal_uInt8 nID);
+    XFColor GetHighlightColor(sal_uInt8 nID);
 private:
     LwpGlobalMgr(LwpSvStream* pSvStream);
 private:
diff --git a/lotuswordpro/source/filter/lwpoverride.cxx b/lotuswordpro/source/filter/lwpoverride.cxx
index 30ea479..2feb62b 100644
--- a/lotuswordpro/source/filter/lwpoverride.cxx
+++ b/lotuswordpro/source/filter/lwpoverride.cxx
@@ -168,7 +168,7 @@ void LwpTextAttributeOverride::Read(LwpObjectStream* pStrm)
     pStrm->SkipExtra();
 }
 
-sal_Bool LwpTextAttributeOverride::IsHighLight()
+sal_Bool LwpTextAttributeOverride::IsHighlight()
 {
     return (m_nValues & TAO_HIGHLIGHT);
 }
diff --git a/lotuswordpro/source/filter/lwpoverride.hxx b/lotuswordpro/source/filter/lwpoverride.hxx
index 71a9385..c01d2ae 100644
--- a/lotuswordpro/source/filter/lwpoverride.hxx
+++ b/lotuswordpro/source/filter/lwpoverride.hxx
@@ -138,7 +138,7 @@ public:
 
     inline sal_uInt16 GetHideLevels() const;
 
-    sal_Bool IsHighLight();
+    sal_Bool IsHighlight();
 
 protected:
     LwpTextAttributeOverride(LwpTextAttributeOverride const& rOther);
diff --git a/offapi/com/sun/star/style/CharacterProperties.idl b/offapi/com/sun/star/style/CharacterProperties.idl
index ae8313d..b4dbf62 100644
--- a/offapi/com/sun/star/style/CharacterProperties.idl
+++ b/offapi/com/sun/star/style/CharacterProperties.idl
@@ -439,7 +439,7 @@ published service CharacterProperties
      *
      *  @since LibreOffice 4.2
     **/
-    [optional, property] com::sun::star::util::Color CharHighLight;
+    [optional, property] com::sun::star::util::Color CharHighlight;
 
 };
 
diff --git a/sc/source/ui/inc/anyrefdg.hxx b/sc/source/ui/inc/anyrefdg.hxx
index 85f6d23..cfc0b5c 100644
--- a/sc/source/ui/inc/anyrefdg.hxx
+++ b/sc/source/ui/inc/anyrefdg.hxx
@@ -66,7 +66,7 @@ class ScFormulaReferenceHelper
     bool                mbOldEditParentLayoutEnabled;  // Original layout state of edit widget parent
 
     bool                bEnableColorRef;
-    bool                bHighLightRef;
+    bool                bHighlightRef;
     bool                bAccInserted;
 
     DECL_LINK( AccelSelectHdl, Accelerator* );
diff --git a/sc/source/ui/inc/highred.hxx b/sc/source/ui/inc/highred.hxx
index 34aaa5e..61d9a8c 100644
--- a/sc/source/ui/inc/highred.hxx
+++ b/sc/source/ui/inc/highred.hxx
@@ -78,7 +78,7 @@ private:
     void                    Init();
 
     DECL_LINK( RefHandle, SvxTPFilter* );
-    DECL_LINK(HighLightHandle, CheckBox*);
+    DECL_LINK(HighlightHandle, CheckBox*);
     DECL_LINK(OKBtnHdl, PushButton*);
 
 
diff --git a/sc/source/ui/miscdlgs/anyrefdg.cxx b/sc/source/ui/miscdlgs/anyrefdg.cxx
index de361eb..2622426 100644
--- a/sc/source/ui/miscdlgs/anyrefdg.cxx
+++ b/sc/source/ui/miscdlgs/anyrefdg.cxx
@@ -54,7 +54,7 @@ ScFormulaReferenceHelper::ScFormulaReferenceHelper(IAnyRefDialog* _pDlg,SfxBindi
  , mpOldEditParent( NULL )
  , mbOldDlgLayoutEnabled( false )
  , mbOldEditParentLayoutEnabled( false )
- , bHighLightRef( false )
+ , bHighlightRef( false )
  , bAccInserted( false )
 {
     ScInputOptions aInputOption=SC_MOD()->GetInputOptions();
@@ -116,7 +116,7 @@ void ScFormulaReferenceHelper::ShowSimpleReference(const OUString& rStr)
 {
     if( bEnableColorRef )
     {
-        bHighLightRef=true;
+        bHighlightRef=true;
         ScViewData* pViewData=ScDocShell::GetViewData();
         if ( pViewData )
         {
@@ -176,7 +176,7 @@ void ScFormulaReferenceHelper::ShowFormulaReference(const OUString& rStr)
 {
     if( bEnableColorRef)
     {
-        bHighLightRef=true;
+        bHighlightRef=true;
         ScViewData* pViewData=ScDocShell::GetViewData();
         if ( pViewData && pRefComp.get() )
         {
@@ -234,7 +234,7 @@ void ScFormulaReferenceHelper::HideReference( bool bDoneRefMode )
 {
     ScViewData* pViewData=ScDocShell::GetViewData();
 
-    if( pViewData && bHighLightRef && bEnableColorRef)
+    if( pViewData && bHighlightRef && bEnableColorRef)
     {
         ScTabViewShell* pTabViewShell=pViewData->GetViewShell();
 
@@ -247,7 +247,7 @@ void ScFormulaReferenceHelper::HideReference( bool bDoneRefMode )
                 pTabViewShell->DoneRefMode( false );
             pTabViewShell->ClearHighlightRanges();
         }
-        bHighLightRef=false;
+        bHighlightRef=false;
     }
 }
 // -----------------------------------------------------------------------------
diff --git a/sc/source/ui/miscdlgs/highred.cxx b/sc/source/ui/miscdlgs/highred.cxx
index b86780f..3652ae1 100644
--- a/sc/source/ui/miscdlgs/highred.cxx
+++ b/sc/source/ui/miscdlgs/highred.cxx
@@ -70,7 +70,7 @@ ScHighlightChgDlg::ScHighlightChgDlg( SfxBindings* pB, SfxChildWindow* pCW, Wind
     MinSize.Height()+=2;
     MinSize.Width()+=2;
     aOkButton.SetClickHdl(LINK( this, ScHighlightChgDlg, OKBtnHdl));
-    aHighlightBox.SetClickHdl(LINK( this, ScHighlightChgDlg, HighLightHandle ));
+    aHighlightBox.SetClickHdl(LINK( this, ScHighlightChgDlg, HighlightHandle ));
     aFilterCtr.SetRefHdl(LINK( this, ScHighlightChgDlg, RefHandle ));
     aFilterCtr.HideRange(false);
     aFilterCtr.Show();
@@ -140,7 +140,7 @@ void ScHighlightChgDlg::Init()
         aFilterCtr.SetRange(aRefStr);
     }
     aFilterCtr.Enable(sal_True,sal_True);
-    HighLightHandle(&aHighlightBox);
+    HighlightHandle(&aHighlightBox);
 }
 
 //----------------------------------------------------------------------------
@@ -186,7 +186,7 @@ sal_Bool ScHighlightChgDlg::IsRefInputMode() const
     return aEdAssign.IsVisible();
 }
 
-IMPL_LINK( ScHighlightChgDlg, HighLightHandle, CheckBox*, pCb )
+IMPL_LINK( ScHighlightChgDlg, HighlightHandle, CheckBox*, pCb )
 {
     if(pCb!=NULL)
     {
diff --git a/sw/inc/charatr.hxx b/sw/inc/charatr.hxx
index e248205..da9e34a 100644
--- a/sw/inc/charatr.hxx
+++ b/sw/inc/charatr.hxx
@@ -87,7 +87,7 @@ inline const SvxBlinkItem  &SwAttrSet::GetBlink(sal_Bool bInP) const
     {   return (const SvxBlinkItem&)Get( RES_CHRATR_BLINK,bInP); }
 inline const SvxBrushItem &SwAttrSet::GetChrBackground( sal_Bool bInP ) const
     {   return (const SvxBrushItem&)Get( RES_CHRATR_BACKGROUND, bInP ); }
-inline const SvxBrushItem &SwAttrSet::GetChrHighLight( sal_Bool bInP ) const
+inline const SvxBrushItem &SwAttrSet::GetChrHighlight( sal_Bool bInP ) const
     {   return (const SvxBrushItem&)Get( RES_CHRATR_HIGHLIGHT, bInP ); }
 inline const SvxEmphasisMarkItem &SwAttrSet::GetEmphasisMark( sal_Bool bInP ) const
     {   return (const SvxEmphasisMarkItem&)Get( RES_CHRATR_EMPHASIS_MARK, bInP ); }
@@ -154,8 +154,8 @@ inline const SvxBlinkItem           &SwFmt::GetBlink(sal_Bool bInP) const
     {   return aSet.GetBlink(bInP); }
 inline const SvxBrushItem           &SwFmt::GetChrBackground(sal_Bool bInP) const
     {   return aSet.GetChrBackground(bInP); }
-inline const SvxBrushItem &SwFmt::GetChrHighLight(sal_Bool bInP) const
-    {   return aSet.GetChrHighLight(bInP); }
+inline const SvxBrushItem &SwFmt::GetChrHighlight(sal_Bool bInP) const
+    {   return aSet.GetChrHighlight(bInP); }
 inline const SvxEmphasisMarkItem   &SwFmt::GetEmphasisMark( sal_Bool bInP ) const
     {   return aSet.GetEmphasisMark(bInP); }
 inline const SvxTwoLinesItem       &SwFmt::Get2Lines( sal_Bool bInP ) const
diff --git a/sw/inc/format.hxx b/sw/inc/format.hxx
index 88c5402..5463e9f 100644
--- a/sw/inc/format.hxx
+++ b/sw/inc/format.hxx
@@ -190,7 +190,7 @@ public:
     inline const SvxNoHyphenItem     &GetNoHyphenHere( sal_Bool = sal_True ) const;
     inline const SvxBlinkItem        &GetBlink( sal_Bool = sal_True ) const;
     inline const SvxBrushItem        &GetChrBackground( sal_Bool = sal_True ) const;
-    inline const SvxBrushItem        &GetChrHighLight( sal_Bool = sal_True ) const;
+    inline const SvxBrushItem        &GetChrHighlight( sal_Bool = sal_True ) const;
 
     inline const SvxFontItem         &GetCJKFont( sal_Bool = sal_True ) const;
     inline const SvxFontHeightItem   &GetCJKSize( sal_Bool = sal_True ) const;
diff --git a/sw/inc/swatrset.hxx b/sw/inc/swatrset.hxx
index 8c1c87b..e713d4c 100644
--- a/sw/inc/swatrset.hxx
+++ b/sw/inc/swatrset.hxx
@@ -232,7 +232,7 @@ public:
     inline const SvxNoHyphenItem      &GetNoHyphenHere( sal_Bool = sal_True ) const;
     inline const SvxBlinkItem         &GetBlink( sal_Bool = sal_True ) const;
     inline const SvxBrushItem         &GetChrBackground( sal_Bool = sal_True ) const;
-    inline const SvxBrushItem         &GetChrHighLight( sal_Bool = sal_True ) const;
+    inline const SvxBrushItem         &GetChrHighlight( sal_Bool = sal_True ) const;
     inline const SvxFontItem          &GetCJKFont( sal_Bool = sal_True ) const;
     inline const SvxFontHeightItem    &GetCJKSize( sal_Bool = sal_True ) const;
     inline const SvxLanguageItem      &GetCJKLanguage( sal_Bool = sal_True ) const;
diff --git a/sw/qa/extras/ooxmlexport/ooxmlexport.cxx b/sw/qa/extras/ooxmlexport/ooxmlexport.cxx
index 49f90e6..223f26f 100644
--- a/sw/qa/extras/ooxmlexport/ooxmlexport.cxx
+++ b/sw/qa/extras/ooxmlexport/ooxmlexport.cxx
@@ -121,7 +121,7 @@ public:
     void testStyleInheritance();
     void testSmartart();
     void testFdo69636();
-    void testCharHighLight();
+    void testCharHighlight();
 
     CPPUNIT_TEST_SUITE(Test);
 #if !defined(MACOSX) && !defined(WNT)
@@ -240,7 +240,7 @@ void Test::run()
         {"style-inheritance.docx", &Test::testStyleInheritance},
         {"smartart.docx", &Test::testSmartart},
         {"fdo69636.docx", &Test::testFdo69636},
-        {"char_highlight.docx", &Test::testCharHighLight},
+        {"char_highlight.docx", &Test::testCharHighlight},
     };
     // Don't test the first import of these, for some reason those tests fail
     const char* aBlacklist[] = {
@@ -1503,7 +1503,7 @@ void Test::testFdo69636()
     CPPUNIT_ASSERT(getXPath(pXmlDoc, "/w:document/w:body/w:p/w:r/w:pict/v:rect/v:textbox", "style").match("mso-layout-flow-alt:bottom-to-top"));
 }
 
-void Test::testCharHighLight()
+void Test::testCharHighlight()
 {
     const uno::Reference< text::XTextRange > xPara = getParagraph(1);
     // Both highlight and background
@@ -1511,41 +1511,41 @@ void Test::testCharHighLight()
     for( int nRun = 1; nRun <= 16; ++nRun )
     {
         const uno::Reference<beans::XPropertySet> xRun(getRun(xPara,nRun), uno::UNO_QUERY);
-        sal_Int32 nHighLightColor = 0;
+        sal_Int32 nHighlightColor = 0;
         switch( nRun )
         {
-            case 1: nHighLightColor = 0x000000; break; //black
-            case 2: nHighLightColor = 0x0000ff; break; //blue
-            case 3: nHighLightColor = 0x00ffff; break; //cyan
-            case 4: nHighLightColor = 0x00ff00; break; //green
-            case 5: nHighLightColor = 0xff00ff; break; //magenta
-            case 6: nHighLightColor = 0xff0000; break; //red
-            case 7: nHighLightColor = 0xffff00; break; //yellow
-            case 8: nHighLightColor = 0xffffff; break; //white
-            case 9: nHighLightColor = 0x000080;  break;//dark blue
-            case 10: nHighLightColor = 0x008080; break; //dark cyan
-            case 11: nHighLightColor = 0x008000; break; //dark green
-            case 12: nHighLightColor = 0x800080; break; //dark magenta
-            case 13: nHighLightColor = 0x800000; break; //dark red
-            case 14: nHighLightColor = 0x808000; break; //dark yellow
-            case 15: nHighLightColor = 0x808080; break; //dark gray
-            case 16: nHighLightColor = 0xC0C0C0; break; //light gray
+            case 1: nHighlightColor = 0x000000; break; //black
+            case 2: nHighlightColor = 0x0000ff; break; //blue
+            case 3: nHighlightColor = 0x00ffff; break; //cyan
+            case 4: nHighlightColor = 0x00ff00; break; //green
+            case 5: nHighlightColor = 0xff00ff; break; //magenta
+            case 6: nHighlightColor = 0xff0000; break; //red
+            case 7: nHighlightColor = 0xffff00; break; //yellow
+            case 8: nHighlightColor = 0xffffff; break; //white
+            case 9: nHighlightColor = 0x000080;  break;//dark blue
+            case 10: nHighlightColor = 0x008080; break; //dark cyan
+            case 11: nHighlightColor = 0x008000; break; //dark green
+            case 12: nHighlightColor = 0x800080; break; //dark magenta
+            case 13: nHighlightColor = 0x800000; break; //dark red
+            case 14: nHighlightColor = 0x808000; break; //dark yellow
+            case 15: nHighlightColor = 0x808080; break; //dark gray
+            case 16: nHighlightColor = 0xC0C0C0; break; //light gray
         }
-        CPPUNIT_ASSERT_EQUAL(nHighLightColor, getProperty<sal_Int32>(xRun,"CharHighLight"));
+        CPPUNIT_ASSERT_EQUAL(nHighlightColor, getProperty<sal_Int32>(xRun,"CharHighlight"));
         CPPUNIT_ASSERT_EQUAL(nBackColor, getProperty<sal_Int32>(xRun,"CharBackColor"));
     }
 
     // Only highlight
     {
         const uno::Reference<beans::XPropertySet> xRun(getRun(xPara,17), uno::UNO_QUERY);
-        CPPUNIT_ASSERT_EQUAL(sal_Int32(0xC0C0C0), getProperty<sal_Int32>(xRun,"CharHighLight"));
+        CPPUNIT_ASSERT_EQUAL(sal_Int32(0xC0C0C0), getProperty<sal_Int32>(xRun,"CharHighlight"));
         CPPUNIT_ASSERT_EQUAL(sal_Int32(COL_TRANSPARENT), getProperty<sal_Int32>(xRun,"CharBackColor"));
     }
 
     // Only background
     {
         const uno::Reference<beans::XPropertySet> xRun(getRun(xPara,18), uno::UNO_QUERY);
-        CPPUNIT_ASSERT_EQUAL(sal_Int32(COL_TRANSPARENT), getProperty<sal_Int32>(xRun,"CharHighLight"));
+        CPPUNIT_ASSERT_EQUAL(sal_Int32(COL_TRANSPARENT), getProperty<sal_Int32>(xRun,"CharHighlight"));
         CPPUNIT_ASSERT_EQUAL(sal_Int32(0x0000ff), getProperty<sal_Int32>(xRun,"CharBackColor"));
     }
 }
diff --git a/sw/source/core/inc/swfont.hxx b/sw/source/core/inc/swfont.hxx
index b6c0e2b..8f7338f 100644
--- a/sw/source/core/inc/swfont.hxx
+++ b/sw/source/core/inc/swfont.hxx
@@ -127,7 +127,7 @@ class SwFont
                                 // CTL == Complex text layout ( Hebrew, Arabic )
     SwSubFont   aSub[SW_SCRIPTS]; // Latin-, CJK- and CTL-font
     Color*      pBackColor;     // background color (i.e. at character styles)
-    Color       m_aHighLightColor;   // highlight color
+    Color       m_aHighlightColor;   // highlight color
     Color       aUnderColor;    // color of the underlining
     Color       aOverColor;     // color of the overlining
 
@@ -183,8 +183,8 @@ public:
     // set background color
     void SetBackColor( Color* pNewColor );
     inline const Color* GetBackColor() const{ return pBackColor; }
-    void SetHighLightColor( const Color& aNewColor );
-    const Color& GetHighLightColor() const { return m_aHighLightColor; }
+    void SetHighlightColor( const Color& aNewColor );
+    const Color& GetHighlightColor() const { return m_aHighlightColor; }
 
     inline void ChkMagic( ViewShell *pSh, sal_uInt8 nWhich )
         { if( !aSub[ nWhich ].pMagic ) GoMagic( pSh, nWhich ); }
@@ -1003,9 +1003,9 @@ inline void SwFont::SetShadowLocation( const SvxShadowLocation aLocation )
     aSub[SW_LATIN].pMagic = aSub[SW_CJK].pMagic = aSub[SW_CTL].pMagic = 0;
 }
 
-inline void SwFont::SetHighLightColor( const Color& aNewColor )
+inline void SwFont::SetHighlightColor( const Color& aNewColor )
 {
-    m_aHighLightColor = aNewColor;
+    m_aHighlightColor = aNewColor;
     bFntChg = sal_True;
     aSub[SW_LATIN].pMagic = aSub[SW_CJK].pMagic = aSub[SW_CTL].pMagic = 0;
 }
diff --git a/sw/source/core/text/atrstck.cxx b/sw/source/core/text/atrstck.cxx
index ad1c2a9..08c3d99 100644
--- a/sw/source/core/text/atrstck.cxx
+++ b/sw/source/core/text/atrstck.cxx
@@ -798,7 +798,7 @@ void SwAttrHandler::FontChg(const SfxPoolItem& rItem, SwFont& rFnt, sal_Bool bPu
             rFnt.SetBackColor(new Color( ((SvxBrushItem&)rItem).GetColor() ) );
             break;
         case RES_CHRATR_HIGHLIGHT :
-            rFnt.SetHighLightColor( ((SvxBrushItem&)rItem).GetColor() );
+            rFnt.SetHighlightColor( ((SvxBrushItem&)rItem).GetColor() );
             break;
         case RES_CHRATR_CJK_FONT :
             rFnt.SetName( ((SvxFontItem&)rItem).GetFamilyName(), SW_CJK );
diff --git a/sw/source/core/text/inftxt.cxx b/sw/source/core/text/inftxt.cxx
index 2de233c..cbb7ee6 100644
--- a/sw/source/core/text/inftxt.cxx
+++ b/sw/source/core/text/inftxt.cxx
@@ -1184,9 +1184,9 @@ void SwTxtPaintInfo::DrawBackBrush( const SwLinePortion &rPor ) const
 
         pTmpOut->Push( PUSH_LINECOLOR | PUSH_FILLCOLOR );
 
-        if( m_pFnt->GetHighLightColor() != COL_TRANSPARENT )
+        if( m_pFnt->GetHighlightColor() != COL_TRANSPARENT )
         {
-            pTmpOut->SetFillColor( m_pFnt->GetHighLightColor() );
+            pTmpOut->SetFillColor( m_pFnt->GetHighlightColor() );
         }
         else
         {
diff --git a/sw/source/core/txtnode/swfont.cxx b/sw/source/core/txtnode/swfont.cxx
index 275e2a5..eef49fa 100644
--- a/sw/source/core/txtnode/swfont.cxx
+++ b/sw/source/core/txtnode/swfont.cxx
@@ -667,7 +667,7 @@ void SwFont::SetDiffFnt( const SfxItemSet *pAttrSet,
             pBackColor = new Color( ((SvxBrushItem*)pItem)->GetColor() );
         if( SFX_ITEM_SET == pAttrSet->GetItemState( RES_CHRATR_HIGHLIGHT,
             sal_True, &pItem ))
-            SetHighLightColor(((SvxBrushItem*)pItem)->GetColor());
+            SetHighlightColor(((SvxBrushItem*)pItem)->GetColor());
         if( SFX_ITEM_SET == pAttrSet->GetItemState( RES_CHRATR_BOX,
             sal_True, &pItem ))
         {
@@ -715,7 +715,7 @@ SwFont::SwFont( const SwFont &rFont )
     aSub[SW_CTL] = rFont.aSub[SW_CTL];
     nActual = rFont.nActual;
     pBackColor = rFont.pBackColor ? new Color( *rFont.pBackColor ) : NULL;
-    m_aHighLightColor = rFont.m_aHighLightColor;
+    m_aHighlightColor = rFont.m_aHighlightColor;
     m_aTopBorder = rFont.m_aTopBorder;
     m_aBottomBorder = rFont.m_aBottomBorder;
     m_aRightBorder = rFont.m_aRightBorder;
@@ -849,9 +849,9 @@ SwFont::SwFont( const SwAttrSet* pAttrSet,
         pBackColor = NULL;
     if( SFX_ITEM_SET == pAttrSet->GetItemState( RES_CHRATR_HIGHLIGHT,
         sal_True, &pItem ))
-        SetHighLightColor(((SvxBrushItem*)pItem)->GetColor());
+        SetHighlightColor(((SvxBrushItem*)pItem)->GetColor());
     else
-        SetHighLightColor(COL_TRANSPARENT);
+        SetHighlightColor(COL_TRANSPARENT);
     if( SFX_ITEM_SET == pAttrSet->GetItemState( RES_CHRATR_BOX,
         sal_True, &pItem ))
     {
@@ -931,7 +931,7 @@ SwFont& SwFont::operator=( const SwFont &rFont )
     nActual = rFont.nActual;
     delete pBackColor;
     pBackColor = rFont.pBackColor ? new Color( *rFont.pBackColor ) : NULL;
-    m_aHighLightColor = rFont.m_aHighLightColor;
+    m_aHighlightColor = rFont.m_aHighlightColor;
     m_aTopBorder = rFont.m_aTopBorder;
     m_aBottomBorder = rFont.m_aBottomBorder;
     m_aRightBorder = rFont.m_aRightBorder;
diff --git a/sw/source/core/unocore/unoprnms.cxx b/sw/source/core/unocore/unoprnms.cxx
index 6f09ce6..740c8fd 100644
--- a/sw/source/core/unocore/unoprnms.cxx
+++ b/sw/source/core/unocore/unoprnms.cxx
@@ -805,7 +805,7 @@ const SwPropNameTab aPropNameTab = {
 /* 0773 UNO_NAME_SHADOW_TRANSPARENCE */                {MAP_CHAR_LEN("ShadowTransparence")},
 /* 0774 UNO_NAME_DOC_INTEROP_GRAB_BAG */               {MAP_CHAR_LEN("InteropGrabBag")},
 /* 0775 UNO_NAME_FRAME_INTEROP_GRAB_BAG */             {MAP_CHAR_LEN("FrameInteropGrabBag")},
-/* 0776 UNO_NAME_CHAR_HIGHLIGHT */                     {MAP_CHAR_LEN("CharHighLight")},
+/* 0776 UNO_NAME_CHAR_HIGHLIGHT */                     {MAP_CHAR_LEN("CharHighlight")},
 
 // new items in this array must match enum SwPropNameIds
 };
diff --git a/sw/source/filter/ww8/attributeoutputbase.hxx b/sw/source/filter/ww8/attributeoutputbase.hxx
index 9ead9085..c25f648 100644
--- a/sw/source/filter/ww8/attributeoutputbase.hxx
+++ b/sw/source/filter/ww8/attributeoutputbase.hxx
@@ -445,7 +445,7 @@ protected:
     virtual void CharBorder( const ::editeng::SvxBorderLine* pAllBorder, const sal_uInt16 nDist, const bool bShadow ) = 0;
 
     /// Sfx item RES_CHRATR_HIGHLIGHT
-    virtual void CharHighLight( const SvxBrushItem& ) = 0;
+    virtual void CharHighlight( const SvxBrushItem& ) = 0;
 
     /// Sfx item RES_TXTATR_INETFMT
     virtual void TextINetFormat( const SwFmtINetFmt& ) = 0;
diff --git a/sw/source/filter/ww8/docxattributeoutput.cxx b/sw/source/filter/ww8/docxattributeoutput.cxx
index b1e287b..d215e25 100644
--- a/sw/source/filter/ww8/docxattributeoutput.cxx
+++ b/sw/source/filter/ww8/docxattributeoutput.cxx
@@ -3815,7 +3815,7 @@ void DocxAttributeOutput::EmbedFontStyle( const OUString& name, int tag, FontFam
         FSEND );
 }
 
-OString DocxAttributeOutput::TransHighLightColor( const Color& rColor )
+OString DocxAttributeOutput::TransHighlightColor( const Color& rColor )
 {
     switch (rColor.GetColor())
     {
@@ -4424,9 +4424,9 @@ void DocxAttributeOutput::CharBorder(
     impl_borderLine( m_pSerializer, XML_bdr, pAllBorder, nDist, bShadow );
 }
 
-void DocxAttributeOutput::CharHighLight( const SvxBrushItem& rHighLight )
+void DocxAttributeOutput::CharHighlight( const SvxBrushItem& rHighlight )
 {
-    const OString sColor = TransHighLightColor( rHighLight.GetColor() );
+    const OString sColor = TransHighlightColor( rHighlight.GetColor() );
     if ( !sColor.isEmpty() )
     {
         m_pSerializer->singleElementNS( XML_w, XML_highlight,
diff --git a/sw/source/filter/ww8/rtfattributeoutput.hxx b/sw/source/filter/ww8/rtfattributeoutput.hxx
index fc2f3ce5..aeb5264 100644
--- a/sw/source/filter/ww8/rtfattributeoutput.hxx
+++ b/sw/source/filter/ww8/rtfattributeoutput.hxx
@@ -316,7 +316,7 @@ protected:
     virtual void CharBorder( const ::editeng::SvxBorderLine* pAllBorder, const sal_uInt16 nDist, const bool bShadow );
 
     /// Sfx item RES_CHRATR_HIGHLIGHT
-    virtual void CharHighLight( const SvxBrushItem& ){};
+    virtual void CharHighlight( const SvxBrushItem& ){};
 
     /// Sfx item RES_TXTATR_INETFMT
     virtual void TextINetFormat( const SwFmtINetFmt& );
diff --git a/sw/source/filter/ww8/ww8atr.cxx b/sw/source/filter/ww8/ww8atr.cxx
index 32f46b8..dc3117a 100644
--- a/sw/source/filter/ww8/ww8atr.cxx
+++ b/sw/source/filter/ww8/ww8atr.cxx
@@ -5145,7 +5145,7 @@ void AttributeOutputBase::OutputItem( const SfxPoolItem& rHt )
             FormatCharBorder( static_cast< const SvxBoxItem& >( rHt ) );
             break;
         case RES_CHRATR_HIGHLIGHT:
-            CharHighLight( static_cast< const SvxBrushItem& >( rHt ) );
+            CharHighlight( static_cast< const SvxBrushItem& >( rHt ) );
             break;
 
         case RES_TXTATR_INETFMT:
diff --git a/sw/source/filter/ww8/ww8attributeoutput.hxx b/sw/source/filter/ww8/ww8attributeoutput.hxx
index bcb5f17..24346d7 100644
--- a/sw/source/filter/ww8/ww8attributeoutput.hxx
+++ b/sw/source/filter/ww8/ww8attributeoutput.hxx
@@ -297,7 +297,7 @@ protected:
     virtual void CharBorder( const ::editeng::SvxBorderLine* pAllBorder, const sal_uInt16 nDist, const bool bShadow );
 
     /// Sfx item RES_CHRATR_HIGHLIGHT
-    virtual void CharHighLight( const SvxBrushItem& ){};
+    virtual void CharHighlight( const SvxBrushItem& ){};
 
     /// Sfx item RES_TXTATR_INETFMT
     virtual void TextINetFormat( const SwFmtINetFmt& );
diff --git a/writerfilter/source/dmapper/PropertyIds.cxx b/writerfilter/source/dmapper/PropertyIds.cxx
index f72b4d6..9cdd249 100644
--- a/writerfilter/source/dmapper/PropertyIds.cxx
+++ b/writerfilter/source/dmapper/PropertyIds.cxx
@@ -114,7 +114,7 @@ const OUString& PropertyNameSupplier::GetName( PropertyIds eId ) const
             case PROP_CHAR_TOP_BORDER_DISTANCE: sName = "CharTopBorderDistance";break;
             case PROP_CHAR_BOTTOM_BORDER_DISTANCE: sName = "CharBottomBorderDistance"; break;
             case PROP_CHAR_SHADOW_FORMAT: sName = "CharShadowFormat"; break;
-            case PROP_CHAR_HIGHLIGHT: sName = "CharHighLight"; break;
+            case PROP_CHAR_HIGHLIGHT: sName = "CharHighlight"; break;
 
             case PROP_PARA_STYLE_NAME:      sName = "ParaStyleName"; break;
             case PROP_PARA_ADJUST:     sName = "ParaAdjust"; break;


More information about the Libreoffice-commits mailing list
diff --git a/sw/source/filter/ww8/docxattributeoutput.hxx b/sw/source/filter/ww8/docxattributeoutput.hxx
index a7242e3..2e99f9d 100644
--- a/sw/source/filter/ww8/docxattributeoutput.hxx
+++ b/sw/source/filter/ww8/docxattributeoutput.hxx
@@ -377,13 +377,13 @@ private:
         FontPitch pitch, rtl_TextEncoding encoding );
 
     /**
      * Translate a color object to the corresponding HighLightColorValues enumaration item
      *
      * @param[in]   rColor      a color object to translate
      * @return      color name (e.g. "red"), if color is inside the enumeration's range
      *              empty string, otherwise
     **/
-    OString TransHighLightColor( const Color& rColor );
+    OString TransHighlightColor( const Color& rColor );
 protected:
 
     /// Output frames - the implementation.
@@ -489,7 +489,7 @@ protected:
     virtual void CharBorder( const ::editeng::SvxBorderLine* pAllBorder, const sal_uInt16 nDist, const bool bShadow );
 
     /// Sfx item RES_CHRATR_HIGHLIGHT
-    virtual void CharHighLight( const SvxBrushItem& rHighLight );
+    virtual void CharHighlight( const SvxBrushItem& rHighlight );
 
     /// Sfx item RES_TXTATR_INETFMT
     virtual void TextINetFormat( const SwFmtINetFmt& );
@@ -377,13 +377,13 @@ private:
 
     /**
-     * Translate a color object to the corresponding HighLightColorValues enumaration item
+     * Translate a color object to the corresponding HighlightColorValues enumaration item
      *
      * @param[in]   rColor      a color object to translate